==> haskell-hspec-golden-0.2.1.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-golden
version:              0.2.1.0
visibility:           public
id:                   hspec-golden-0.2.1.0-JIMYJLRjJmI6cbFdlFAVnU
key:                  hspec-golden-0.2.1.0-JIMYJLRjJmI6cbFdlFAVnU
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  02b9a198e79dd6e0ad8761218f4f7408
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.1.0-JIMYJLRjJmI6cbFdlFAVnU
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    hspec-core-2.10.10-5DyNQosPxlf2uYMBMaWjMR

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-golden-0.2.1.0-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-golden
version:              0.2.1.0
visibility:           public
id:                   hspec-golden-0.2.1.0-Dv8fWaDt0p1Ez3kWk9MsPd
key:                  hspec-golden-0.2.1.0-Dv8fWaDt0p1Ez3kWk9MsPd
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  85cd1b99cab5559804c1777732826bef
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.1.0-Dv8fWaDt0p1Ez3kWk9MsPd
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    hspec-core-2.10.10-CgIkKb4SbH941pFcVc3rKE

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
